@@ -15,21 +15,16 @@ def read_machine_code() :
     return read(MACHINE_CODE_PATH)
 
 
-def gen_user_code(bit=8, to_file=True) :
+def gen_user_code(days=3, crypt=CRYPT, to_file=True) :
     '''
-    管理员场景： 随机分配用户码，并写入文件
+    管理员场景： 分配用户码，并写入文件
     （可直接把文件发送给用户，让其放到程序根目录）
-    [param] bit: 用户码位数
+    [param] day: 授权天数。 0 为永久授权
     [param] to_file: 是否把用户码写入文件
     [return] 用户码
     '''
-    str_range = "%s%s" % (
-        string.ascii_letters, 
-        string.digits
-    )
-    user_code = ''.join(
-        random.sample(str_range, bit)
-    )
+    after_time = after(int(days))
+    user_code = crypt.encrypt_des(after_time)
     if to_file :
         save(user_code, USER_CODE_PATH)
     return user_code
@@ -51,7 +46,8 @@ def gen_register_code(machine_code, user_code, crypt=CRYPT, to_file=True) :
     '''
     try :
         uuid = crypt.decrypt_des(machine_code)
-        register_code = gen_rc(crypt, uuid, user_code)
+        expire_time = crypt.decrypt_des(user_code)
+        register_code = gen_rc(crypt, uuid, expire_time)
     except :
         register_code = ''
         print('无法解密【机器码】：加密密钥不同、或加密格式不正确')
